@@ -101,6 +101,7 @@ static char *models[] =
 	"AMD Athlon(tm) 64 Processor 3500+", "x86_64",
 	"AMD Athlon(tm) 64 Processor 3700+", "x86_64",
 	"AMD Athlon(tm) 64 X2 Dual Core Processor 5400+", "x86_64",
+	"AMD Athlon(tm) II X4 620 Processor", "Athlon(tm) II",
 	"AMD Phenom(tm) II X6 1055T Processor", "Phenom II",
 	"AMD A6-6310 APU with AMD Radeon R4 Graphics", "A6-6310 with Radeon R4",
 	"AMD FX(tm)-4300 Quad-Core Processor", "x86_64 FX",
@@ -150,6 +151,7 @@ static char *models[] =
 	"Intel(R) Core(TM)2 Duo CPU     E7400  @ 2.80GHz", "Core 2 Duo",
 	"Intel(R) Core(TM)2 Duo CPU     E8400  @ 3.00GHz", "Core 2 Duo",
 	"Intel(R) Core(TM)2 Quad CPU    Q9550  @ 2.83GHz", "Core 2 Quad",
+	"Intel(R) Core(TM) i5-6200U CPU @ 2.30GHz", "Core i5",
 	"Genuine Intel(R) CPU            2140  @ 1.60GHz", "Pentium 4",
         NULL, NULL
 };
